pub struct Drawing { /* private fields */ }opengl only.Implementations
Sourceimpl Drawing
impl Drawing
Sourcepub unsafe fn draw_arrays(&self, start: i32, count: i32, mode: PrimitiveType)
pub unsafe fn draw_arrays(&self, start: i32, count: i32, mode: PrimitiveType)
Renders primitives from array data.
GLError::InvalidValue is generated if count is negative.
GLError::InvalidOperation is generated
if a non-zero buffer object name is bound to an enabled array
and the buffer object’s data store is currently mapped,
or if a geometry shader is active and mode is incompatible
with the input primitive type of the geometry shader in the currently installed program object.
Sourcepub unsafe fn draw_elements(
&self,
start: i32,
count: i32,
index_type: IndexType,
mode: PrimitiveType,
)
pub unsafe fn draw_elements( &self, start: i32, count: i32, index_type: IndexType, mode: PrimitiveType, )
Render primitives from array data.
GLError::InvalidValue is generated if count is negative.
GLError::InvalidOperation is generated
if a non-zero buffer object name is bound to an enabled array or the element array
and the buffer object’s data store is currently mapped,
or if a geometry shader is active and mode is incompatible
with the input primitive type of the geometry shader in the currently installed program object.
Sourcepub unsafe fn draw_elements_typed<T: AvailableIndexType>(
&self,
start: i32,
count: i32,
mode: PrimitiveType,
)
pub unsafe fn draw_elements_typed<T: AvailableIndexType>( &self, start: i32, count: i32, mode: PrimitiveType, )
Renders primitives from array data.
GLError::InvalidValue is generated if count is negative.
GLError::InvalidOperation is generated
if a non-zero buffer object name is bound to an enabled array or the element array
and the buffer object’s data store is currently mapped,
or if a geometry shader is active and mode is incompatible
with the input primitive type of the geometry shader in the currently installed program object.
Sourcepub unsafe fn multi_draw_arrays(
&self,
start: &[i32],
count: &[i32],
mode: PrimitiveType,
)
pub unsafe fn multi_draw_arrays( &self, start: &[i32], count: &[i32], mode: PrimitiveType, )
Renders multiple sets of primitives from array data.
GLError::InvalidOperation is generated
if a non-zero buffer object name is bound to an enabled array
and the buffer object’s data store is currently mapped.
Sourcepub unsafe fn multi_draw_elements(
&self,
start: &[isize],
count: &[i32],
index_type: IndexType,
mode: PrimitiveType,
)
pub unsafe fn multi_draw_elements( &self, start: &[isize], count: &[i32], index_type: IndexType, mode: PrimitiveType, )
Renders multiple sets of primitives by specifying indices of array data elements.
GLError::InvalidOperation is generated
if a non-zero buffer object name is bound to an enabled array or the element array
and the buffer object’s data store is currently mapped.
Sourcepub unsafe fn multi_draw_elements_typed<T: AvailableIndexType>(
&self,
start: &[isize],
count: &[i32],
mode: PrimitiveType,
)
pub unsafe fn multi_draw_elements_typed<T: AvailableIndexType>( &self, start: &[isize], count: &[i32], mode: PrimitiveType, )
Renders multiple sets of primitives by specifying indices of array data elements.
GLError::InvalidOperation is generated
if a non-zero buffer object name is bound to an enabled array or the element array
and the buffer object’s data store is currently mapped.